#!/usr/bin/env python3

import argparse
import shapefile
import numpy as np
from os import path

parser = argparse.ArgumentParser()
parser.add_argument("directory", help = "containing the three shapefiles")
args = parser.parse_args()

n_valid_cycl = 0
n_valid = 0
n_minima = 0
n_radius4 = np.zeros(3, dtype = int)
n_outer = 0
n_points_valid = 0
n_points = 0
n_missing_speed = np.zeros(3, dtype = int)
n_valid_speed = 0

with shapefile.Reader(path.join(args.directory, "extremum")) as extremum, \
     shapefile.Reader(path.join(args.directory, "outermost_contour")) \
     as outermost_contour:
    n_extr = len(extremum)
    
    for rec_extr, shape_rec_outer in zip(extremum.iterRecords(),
                                         outermost_contour):
        if rec_extr.cyclone == 1: n_minima += 1
        l = len(shape_rec_outer.shape.points)
        n_points += l

        if rec_extr.valid == 1:
            n_valid += 1
            n_points_valid += l
            
        if rec_extr.cyclone == 1 and rec_extr.valid == 1: n_valid_cycl += 1
        if shape_rec_outer.record.r_eq_area >= 0: n_outer += 1
        
        if shape_rec_outer.record.radius4 == 0:
            n_radius4[0] += 1
        elif shape_rec_outer.record.radius4 == 1:
            n_radius4[1] += 1
        elif shape_rec_outer.record.radius4 >= 2:
            n_radius4[2] += 1

        if rec_extr.speed == 1e4:
            if shape_rec_outer.record.radius4 == 0:
                n_missing_speed[0] += 1
            elif shape_rec_outer.record.radius4 == 1:
                n_missing_speed[1] += 1
            elif shape_rec_outer.record.radius4 >= 2:
                n_missing_speed[2] += 1
        else:
            n_valid_speed += 1

print("number of extrema of SSH:", n_extr)
print("number of minima of SSH:", n_minima)
print("number of maxima of SSH:", n_extr - n_minima)
print()

print("number of valid eddies (outermost contour found with sufficient area):",
      n_valid)
print("number of valid cyclones:", n_valid_cycl)
print("number of valid anticyclones:", n_valid - n_valid_cycl)
print()

print("number of extrema with radius4 == 0 (no outermost contour or "
      "insufficient area):", n_radius4[0])
print("number of extrema with radius4 == 1 (valid eddies with radius4 == 1):",
      n_radius4[1])
print("number of extrema with radius4 >= 2 (valid eddies with radius4 >= 2):",
      n_radius4[2])
print()

print("number of outermost contours (outermost contour found, but may be with "
      "sufficient area or not):", n_outer)

if n_valid != 0:
    print("average number of points of outermost contour per valid eddy:",
          n_points_valid / n_valid)
    
print("average number of points of outermost contour per extremum (valid eddy "
      "or not):", n_points / n_extr)
print()

print("number of valid speed values:", n_valid_speed)
print("number of missing speed values with radius4 == 0:", n_missing_speed[0])
print("number of missing speed values with radius4 == 1:", n_missing_speed[1])
print("number of missing speed values with radius4 >= 2 (non null shape in "
      "max_speed_contour and missing speed in extremum.dbf):",
      n_missing_speed[2])
print()

n_max_speed = 0
n_points_valid = 0
n_points = 0

with shapefile.Reader(path.join(args.directory, "max_speed_contour")) \
     as max_speed_contour:
    for shape_rec in max_speed_contour:
        l = len(shape_rec.shape.points)
        n_points += l
        if shape_rec.record.r_eq_area >= 0:
            n_max_speed += 1
            n_points_valid += l

print("number of non-null maximum-speed contours (distinct from the "
      "outermost contour, implies radius4 >= 2):",
      n_max_speed)

if n_max_speed != 0:
    print("average number of points of non-null maximum-speed contours:",
          n_points_valid / n_max_speed)
    
print("average number of points of maximum-speed contours, null or not, per "
      "extremum:", n_points / n_extr)
